@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2017 The PHP Group                                |
+   | Copyright (c) 1997-2018 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -24,12 +24,6 @@
 
 #define PHP_SPL_VERSION PHP_VERSION
 
-#if 0
-#define SPL_DEBUG(x)	x
-#else
-#define SPL_DEBUG(x)
-#endif
-
 extern zend_module_entry spl_module_entry;
 #define phpext_spl_ptr &spl_module_entry
 
@@ -62,8 +56,8 @@ PHP_MINFO_FUNCTION(spl);
 ZEND_BEGIN_MODULE_GLOBALS(spl)
 	zend_string *autoload_extensions;
 	HashTable   *autoload_functions;
-	zend_intptr_t     hash_mask_handle;
-	zend_intptr_t     hash_mask_handlers;
+	intptr_t     hash_mask_handle;
+	intptr_t     hash_mask_handlers;
 	int          hash_mask_init;
 	int          autoload_running;
 ZEND_END_MODULE_GLOBALS(spl)
